aboutsummaryrefslogtreecommitdiffstats
path: root/include/llvm/MC/MCAssembler.h
diff options
context:
space:
mode:
authorDaniel Dunbar <daniel@zuster.org>2010-02-13 09:28:54 +0000
committerDaniel Dunbar <daniel@zuster.org>2010-02-13 09:28:54 +0000
commit2be2fd073003c0988723d2894dfb117ad90be11b (patch)
tree474d12cad56fc69fa8a413a9f486093ab47f7a2b /include/llvm/MC/MCAssembler.h
parent0bcf074867d4d366f7988a219c7a53265fcb4f23 (diff)
downloadexternal_llvm-2be2fd073003c0988723d2894dfb117ad90be11b.zip
external_llvm-2be2fd073003c0988723d2894dfb117ad90be11b.tar.gz
external_llvm-2be2fd073003c0988723d2894dfb117ad90be11b.tar.bz2
MCAssembler: Switch MCAsmFixup to storing MCFixupKind instead of just a size.
git-svn-id: https://llvm.org/svn/llvm-project/llvm/trunk@96094 91177308-0d34-0410-b5e6-96231b3b80d8
Diffstat (limited to 'include/llvm/MC/MCAssembler.h')
-rw-r--r--include/llvm/MC/MCAssembler.h9
1 files changed, 5 insertions, 4 deletions
diff --git a/include/llvm/MC/MCAssembler.h b/include/llvm/MC/MCAssembler.h
index 268a3fc..4527f3c 100644
--- a/include/llvm/MC/MCAssembler.h
+++ b/include/llvm/MC/MCAssembler.h
@@ -14,6 +14,7 @@
#include "llvm/ADT/ilist.h"
#include "llvm/ADT/ilist_node.h"
#include "llvm/Support/Casting.h"
+#include "llvm/MC/MCFixup.h"
#include "llvm/System/DataTypes.h"
#include <vector> // FIXME: Shouldn't be needed.
@@ -37,8 +38,8 @@ struct MCAsmFixup {
/// Value - The expression to eventually write into the fragment.
const MCExpr *Value;
- /// Size - The fixup size.
- unsigned Size;
+ /// Kind - The fixup kind.
+ MCFixupKind Kind;
/// FixedValue - The value to replace the fix up by.
//
@@ -46,8 +47,8 @@ struct MCAsmFixup {
uint64_t FixedValue;
public:
- MCAsmFixup(uint64_t _Offset, const MCExpr &_Value, unsigned _Size)
- : Offset(_Offset), Value(&_Value), Size(_Size), FixedValue(0) {}
+ MCAsmFixup(uint64_t _Offset, const MCExpr &_Value, MCFixupKind _Kind)
+ : Offset(_Offset), Value(&_Value), Kind(_Kind), FixedValue(0) {}
};
class MCFragment : public ilist_node<MCFragment> {